Name:		libgap
Version:	4.8.6
Release:	7%{?dist}
License:	GPLv2+
Summary:	C library version of the GAP kernel
URL:		https://bitbucket.org/vbraun/libgap
Source0:	http://files.sagemath.org/spkg/upstream/%{name}/%{name}-%{version}.tar.gz
BuildRequires:	gcc
BuildRequires:	gap-devel
BuildRequires:	gap-libs
BuildRequires:	libtool
BuildRequires:	python2-devel

# The default GAP packages; see /usr/lib/gap/lib/package.gi
Requires:	gap-pkg-alnuth
Requires:	gap-pkg-autpgrp
Requires:	gap-pkg-crisp
Requires:	gap-pkg-ctbllib
Requires:	gap-pkg-factint
Requires:	gap-pkg-fga
Requires:	gap-pkg-irredsol
Requires:	gap-pkg-laguna
Requires:	gap-pkg-polenta
Requires:	gap-pkg-polycyclic
Requires:	gap-pkg-resclasses
Requires:	gap-pkg-sophus
Requires:	gap-pkg-tomlib

# Apply the analog of gap-stat.patch so that the IO package has the necessary
# functions available.
Patch0:		%{name}-stat.patch

# Update libgap with changes in GAP 4.8.7 and 4.8.8 so that the library and
# kernel versions will match.
Patch1:		%{name}-4.8.8.patch

%description
LibGAP -- a C library version of the GAP kernel (http://www.gap-system.org)

LibGAP is essentially a fork of the upstream GAP kernel. It is developed
in its own repository at https://bitbucket.org/vbraun/libgap. This is
also where the spkg metadata is tracked.

%package	devel
Summary:	Development files for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description	devel
This package contains the header files and development documentation
for %{name}.

%prep
%setup -q
%patch0
%patch1

# Regenerate autotools files due to patch 1
autoreconf -fi

%build
export CFLAGS='%{optflags} -D_GNU_SOURCE -DSYS_DEFAULT_PATHS=\"%{_gap_dir}\"'
%configure --enable-shared --disable-static \
  --with-sage=%{_libdir}/sagemath/local LIBS=-lm

# Add some functions we know we have but configure doesn't check for
cat >> src/config.h << EOF

/* Define to 1 if you have the \`atol' function. */
#define HAVE_ATOL 1

/* Define to 1 if you have the \`exp2' function. */
#define HAVE_EXP2 1

/* Define to 1 if you have the \`exp10' function. */
#define HAVE_EXP10 1

/* Define to 1 if you have the \`expm1' function. */
#define HAVE_EXPM1 1

/* Define to 1 if you have the \`log2' function. */
#define HAVE_LOG2 1

/* Define to 1 if you have the \`log10' function. */
#define HAVE_LOG10 1

/* Define to 1 if you have the \`log1p' function. */
#define HAVE_LOG1P 1

/* Define to 1 if you have the \`realpath' function. */
#define HAVE_REALPATH 1

/* Define to 1 if you have the \`sigaction' function. */
#define HAVE_SIGACTION 1

/* Define to 1 if you have the \`sysconf' function. */
#define HAVE_SYSCONF 1

/* Define to 1 if you have the \`trunc' function. */
#define HAVE_TRUNC 1
EOF

# Workaround libtool reordering -Wl,--as-needed after all the libraries
sed -i 's/CC=.g../& -Wl,--as-needed/' libtool

make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
rm %{buildroot}%{_libdir}/*.la

%check
make check

%ldconfig_scriptlets

%files
%doc AUTHORS
%doc README
%license COPYING
%{_libdir}/%{name}.so.4*

%files		devel
%{_includedir}/gap
%{_libdir}/%{name}.so

%changelog
* Sat Jun  2 2018 Jerry James <loganjerry@gmail.com> - 4.8.6-7
- Require the default GAP packages to eliminate warnings

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Nov 23 2017 Jerry James <loganjerry@gmail.com> - 4.8.6-5
- Update -4.8.8 patch to fix one more mismatch

* Tue Nov 21 2017 Jerry James <loganjerry@gmail.com> - 4.8.6-4
- Add -stat patch so the IO package can find the necessary functions
- Add -4.8.8 patch to fix mismatch between library and kernel versions

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Apr  5 2017 Jerry James <loganjerry@gmail.com> - 4.8.6-1
- New upstream release
- Drop all patches, fixed upstream

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu May  5 2016 Jerry James <loganjerry@gmail.com> - 4.8.3-2
- Fix 2 pperm bugs on big endian machines (e.g., ppc64)

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 4.8.3-1
- New upstream release

* Sat Mar  5 2016 Jerry James <loganjerry@gmail.com> - 4.7.9-1
- New upstream release

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.7.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jul 31 2015 Jerry James <loganjerry@gmail.com> - 4.7.8-1
- New upstream release

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.7.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 17 2015 Jerry James <loganjerry@gmail.com> - 4.7.7-1
- New upstream release
- Update URLs
- Use license macro

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.7.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jun 19 2014 Jerry James <loganjerry@gmail.com> - 4.7.5.1-1
- New upstream release

* Thu Jun 19 2014 Jerry James <loganjerry@gmail.com> - 4.7.5-1
- New upstream release

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.7.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Mar 19 2014 Jerry James <loganjerry@gmail.com> - 4.7.4-1
- New upstream release

* Wed Jan 15 2014 Jerry James <loganjerry@gmail.com> - 4.7.2-1
- New upstream release
- Drop upstreamed -arch patch

* Tue Oct  8 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.6.5-3
- Only run x86 specific asm code on x86 (#919703#c17)
- Do not link to gmp as gmp interface is disabled (#919703#c17)

* Sat Oct  5 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.6.5-2
- Make CFLAGS an environment variable (#919703#c12)
- Add gap-libs to build requires (#919703#c12)
- Make package exclusive arch x86.

* Sat Oct  5 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.6.5-1
- Update to version matching rawhide gap (#919703#c8)

* Sat Sep 14 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.6.4.p0-1
- Update to latest version in bz (#919703#c4)

* Fri Feb 22 2013 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.5.7-1
- Initial libgap spec.
